/*
 * Copyright 2010 James Pether Sörling
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *	$Id: ItsYourParliamentEuApiTest.java 4527 2010-09-17 19:13:17Z pether $
 *  $HeadURL: https://cia.svn.sourceforge.net/svnroot/cia/tags/parent-pom-2011.05.31/service.external.itsyourparliament/src/test/java/com/hack23/cia/service/external/itsyourparliament/impl/ItsYourParliamentEuApiTest.java $
*/
package com.hack23.cia.service.external.itsyourparliament.impl;

import java.math.BigInteger;
import java.util.List;

import org.junit.Test;
import org.springframework.beans.factory.annotation.Autowired;

import com.hack23.cia.model.external.itsyourparliament.countries.impl.Countrydetails;
import com.hack23.cia.model.external.itsyourparliament.countryinfo.impl.CountryinfoEuElement;
import com.hack23.cia.model.external.itsyourparliament.mepinfo.impl.MepinfoEuElement;
import com.hack23.cia.model.external.itsyourparliament.voteinfo.impl.VoteinfoEuElement;
import com.hack23.cia.model.external.itsyourparliament.votes.impl.VotesEuData;
import com.hack23.cia.service.external.itsyourparliament.api.ItsYourParliamentEuApi;
import com.hack23.cia.testfoundation.TestInstance;

/**
 * The Class ItsYourParliamentEuApiTest.
 */

public class ItsYourParliamentEuApiTest extends
		AbstractItsYourParliamentEuFunctionalIntegrationTest {

	/** The its your parliament eu api. */
	@Autowired
	ItsYourParliamentEuApi itsYourParliamentEuApi;


	/**
	 * Test get countries.
	 * 
	 * @throws Exception
	 *             the exception
	 */
	@Test
	public void testGetCountries() throws Exception {
		new TestInstance() {

			List<Countrydetails> euCountries = null;
			@Override
			protected void assertPostcondition() {
				assertNotNull(euCountries);
			}

			@Override
			protected void run() {
				try {
					euCountries = itsYourParliamentEuApi.getCountries(null,true);
				} catch (final Exception e) {
					e.printStackTrace();
				}
			}

			@Override
			protected void setupExpectations() {
			}
		}.executeTestPhases();

	}

	/**
	 * Test get countries last term.
	 * 
	 * @throws Exception
	 *             the exception
	 */
	@Test
	public void testGetCountriesLastTerm() throws Exception {
		new TestInstance() {

			List<Countrydetails> euCountries = null;
			@Override
			protected void assertPostcondition() {
				assertNotNull(euCountries);
			}

			@Override
			protected void run() {
				try {
					euCountries = itsYourParliamentEuApi.getCountries(null,false);
				} catch (final Exception e) {
					e.printStackTrace();
				}
			}

			@Override
			protected void setupExpectations() {
			}
		}.executeTestPhases();

	}


	/**
	 * Test get country info.
	 * 
	 * @throws Exception
	 *             the exception
	 */
	@Test
	public void testGetCountryInfo() throws Exception {
		new TestInstance() {

			CountryinfoEuElement sweden = null;
			@Override
			protected void assertPostcondition() {
				assertNotNull(sweden);
			}

			@Override
			protected void run() {
				try {
					sweden = itsYourParliamentEuApi.getCountryInfo(BigInteger.valueOf(14),null,true);
				} catch (final Exception e) {
					e.printStackTrace();
				}
			}

			@Override
			protected void setupExpectations() {
			}
		}.executeTestPhases();

	}

	/**
	 * Test get mep info.
	 * 
	 * @throws Exception
	 *             the exception
	 */
	@Test
	public void testGetMepInfo() throws Exception {
		new TestInstance() {

			MepinfoEuElement mepInfo = null;
			@Override
			protected void assertPostcondition() {
				assertNotNull(mepInfo);
			}

			@Override
			protected void run() {
				try {
					mepInfo = itsYourParliamentEuApi.getMepInfo("398",null,true);
				} catch (final Exception e) {
					e.printStackTrace();
				}
			}

			@Override
			protected void setupExpectations() {
			}
		}.executeTestPhases();

	}

	/**
	 * Test get vote info.
	 * 
	 * @throws Exception
	 *             the exception
	 */
	@Test
	public void testGetVoteInfo() throws Exception {
		new TestInstance() {

			VoteinfoEuElement voteInfo = null;
			@Override
			protected void assertPostcondition() {
				assertNotNull(voteInfo);
			}

			@Override
			protected void run() {
				try {
					voteInfo = itsYourParliamentEuApi.getVoteInfo("581",null,true);
				} catch (final Exception e) {
					e.printStackTrace();
				}
			}

			@Override
			protected void setupExpectations() {
			}
		}.executeTestPhases();

	}

	
	/**
	 * Test get votes.
	 * 
	 * @throws Exception
	 *             the exception
	 */
	@Test
	public void testGetVotes() throws Exception {
		new TestInstance() {

			VotesEuData votes = null;
			@Override
			protected void assertPostcondition() {
				assertTrue(votes.getVote().size() > 0);
			}

			@Override
			protected void run() {
				try {
					votes = itsYourParliamentEuApi.getVotes("2010",null,true);
				} catch (final Exception e) {
					e.printStackTrace();
				}
			}

			@Override
			protected void setupExpectations() {
			}
		}.executeTestPhases();

	}

}
